﻿using System;
using System.Configuration;
using Microsoft.ClearScript.Windows;
using Sonora.Console.Framework.Extensions;

namespace Sonora.Console.Framework
{
    public class SonoraConfig
    {
        public const String CurrentLanguage = "language";
        public const String OutputAutoClear = "output-autoclear";
        public const String OutputAppendNewLine = "output-appendnewline";
        public const String OutputDefaultFileName = "output-defaultfile";
        public const String FolderOutput = "folder-output";
        public const String FolderInput = "folder-input";

        public static SonoraSettings Load()
        {
            var language = ConfigurationManager.AppSettings[CurrentLanguage] ?? "";
            var autoclear = ConfigurationManager.AppSettings[OutputAutoClear].ToBool();
            var addnewline = ConfigurationManager.AppSettings[OutputAppendNewLine].ToBool();
            var outputfolder = ConfigurationManager.AppSettings[FolderOutput] ?? "";
            var inputfolder = ConfigurationManager.AppSettings[FolderInput] ?? "";
            var defaultfilename = ConfigurationManager.AppSettings[OutputDefaultFileName] ?? "";

            var settings = new SonoraSettings() { AppendNewLine = addnewline, AutoClear = autoclear };
            if (String.Equals(language, "vb", StringComparison.InvariantCultureIgnoreCase))
                settings.Engine = new VBScriptEngine();

            if (!String.IsNullOrWhiteSpace(outputfolder))
                settings.OutputFolder = outputfolder;
            if (!String.IsNullOrWhiteSpace(inputfolder))
                settings.InputFolder = inputfolder;
            if (!String.IsNullOrWhiteSpace(defaultfilename))
                settings.DefaultFileName = defaultfilename;
            return settings;
        }
    }
}