﻿using System;
using System.IO;

namespace Sonora.Console.Framework
{
    public class SonoraOutput
    {
        private readonly SonoraSettings _settings;

        public SonoraOutput(SonoraSettings settings = null)
        {
            _settings = settings ?? new SonoraSettings();
        }

        public SonoraOutput print(Object text)
        {
            if (_settings.AutoClear)
                clr();

            printinternal(_settings.Buffer, "{0}", text);

            if (_settings.AppendNewLine)
                _settings.Buffer.Write("\n");

            return this;
        }

        public SonoraOutput print(String format, params Object[] args)
        {
            if (_settings.AutoClear)
                clr();

            printinternal(_settings.Buffer, format, args);

            if (_settings.AppendNewLine)
                _settings.Buffer.Write("\n");

            return this;
        }

        public void file(String filename = "")
        {
            file(filename, "{0}", _settings.Buffer);
        }

        public void file(String filename, Object text)
        {
            file(filename, "{0}", text);
        }

        public void file(String filename, String format, params Object[] args)
        {
            if (String.IsNullOrWhiteSpace(filename))
                filename = _settings.DefaultFileName;
            var fullpath = Path.Combine(_settings.OutputFolder, filename);
            if (!Path.HasExtension(fullpath))
                fullpath = Path.ChangeExtension(fullpath, ".txt");

            var dirname = Path.GetDirectoryName(fullpath);
            if (!String.IsNullOrWhiteSpace(dirname))
                Directory.CreateDirectory(dirname);

            var writer = new StreamWriter(fullpath);
            printinternal(writer, format, args);
            writer.Close();

            if (_settings.AppendNewLine)
                _settings.Buffer.Write("\r\n");

            // Out to screen too
            //print("Saved to file: {0}.", DateTime.Now.ToString("HH:mm:ss"));
        }

        public void clr()
        {
            _settings.Buffer.GetStringBuilder().Clear();
        }

        private void printinternal(TextWriter writer, String format, params Object[] args)
        {
            writer.Write(format, args);
        }
    }
}